new_fixture

Function new_fixture 

fn new_fixture(
    name: String,
    fixture_type_name: String,
    universe: usize,
    channel: ChannelIndex,
) -> (LogLevel, String)
Spawns a new fixture instance based on an existing fixture type at the specified universe and channel.

Arguments

  • name - The name/identifier for the new fixture instance
  • fixture_type_name - The name of the fixture type to instantiate
  • universe - The target universe index
  • channel - The starting channel index