fn new_fixture(
name: String,
fixture_type_name: String,
universe: usize,
channel: ChannelIndex,
) -> (LogLevel, String)Expand description
Spawns a new fixture instance based on an existing fixture type at the specified universe and channel.
Arguments
name- The name/identifier for the new fixture instancefixture_type_name- The name of the fixture type to instantiateuniverse- The target universe indexchannel- The starting channel index