fn new_fixture_type(
name: String,
channels: HashMap<PropertyType, ChannelParameter>,
) -> (LogLevel, String)Expand description
Creates a new fixture type definition with the given name and channel mappings.
Arguments
name- The name of the new fixture typechannels- A map linking property types to their channel parameters